==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/TESTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour TESTPOINTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TESTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTUOM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TESTPOINTID_Type", propOrder = {
    "testpointcode",
    "testpointuom"
})
public class TESTPOINTID_Type {

    @XmlElement(name = "TESTPOINTCODE", required = true)
    protected QUANTITY testpointcode;
    @XmlElement(name = "TESTPOINTUOM", required = true)
    protected UOMID_Type testpointuom;

    /**
     * Obtient la valeur de la propriété testpointcode.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTESTPOINTCODE() {
        return testpointcode;
    }

    /**
     * Définit la valeur de la propriété testpointcode.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTESTPOINTCODE(QUANTITY value) {
        this.testpointcode = value;
    }

    /**
     * Obtient la valeur de la propriété testpointuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getTESTPOINTUOM() {
        return testpointuom;
    }

    /**
     * Définit la valeur de la propriété testpointuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setTESTPOINTUOM(UOMID_Type value) {
        this.testpointuom = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/TESTPOINTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for TESTPOINTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TESTPOINTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TESTPOINTUOM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TESTPOINTID_Type", propOrder = {
    "testpointcode",
    "testpointuom"
})
public class TESTPOINTID_Type {

    @XmlElement(name = "TESTPOINTCODE", required = true)
    protected QUANTITY testpointcode;
    @XmlElement(name = "TESTPOINTUOM", required = true)
    protected UOMID_Type testpointuom;

    /**
     * Gets the value of the testpointcode property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTESTPOINTCODE() {
        return testpointcode;
    }

    /**
     * Sets the value of the testpointcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTESTPOINTCODE(QUANTITY value) {
        this.testpointcode = value;
    }

    /**
     * Gets the value of the testpointuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getTESTPOINTUOM() {
        return testpointuom;
    }

    /**
     * Sets the value of the testpointuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setTESTPOINTUOM(UOMID_Type value) {
        this.testpointuom = value;
    }

}
